﻿using System;
using System.Data;
using System.Drawing;
using System.Windows.Forms;
using System.Data.SqlClient;

namespace Macoratti
{
    public partial class frmMain : Form
    {
        SqlConnection  sqlCon  = new SqlConnection();
        SqlDataAdapter daLivros = new SqlDataAdapter();
        DataSet        dsLivros = new DataSet();

        Boolean isIncluirFlag  = false;
        Boolean isEditarFlag = false;

        public frmMain()
        {
            InitializeComponent();
        }

        private void frmMain_Load(object sender, EventArgs e)
        {
            sqlCon.ConnectionString = @"Data Source=.\SQLEXPRESS;" +
                                       "Initial Catalog=Catalogo;" +
                                       "Integrated Security=True";

            try
            {
                if (sqlCon.State.Equals(ConnectionState.Closed))
                    sqlCon.Open();

                // Seleciona todos os registros
                daLivros.SelectCommand = new SqlCommand("SchLivros");
                daLivros.SelectCommand.CommandType = CommandType.StoredProcedure;
                daLivros.SelectCommand.Connection = sqlCon;
                daLivros.FillSchema(dsLivros, SchemaType.Source, "tblLivros");
                daLivros.Fill(dsLivros, "tblLivros");

                // preenche o datagridview
                dgvLista.DataSource = dsLivros;
                dgvLista.DataMember = "tblLivros";
                formataGridView();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message.ToString());
            }
        }

        private void frmMain_FormClosed(object sender, FormClosedEventArgs e)
        {
            if (sqlCon.State.Equals(ConnectionState.Open))
                sqlCon.Close();
        }

        private void btnIncluir_Click(object sender, EventArgs e)
        {
            txtTitulo.Text = "";
            txtPreco.Text = "";

            SetEnabled(true);
            SetButtons(false);

            isIncluirFlag = true;
        }

        private void dgvLista_CellClick(object sender, DataGridViewCellEventArgs e)
        {
            // é um cabeçalho ?
            if (e.RowIndex > -1)
            {
                // não
                txtTitulo.Text = dgvLista.Rows[e.RowIndex].Cells[2].Value.ToString();
                txtPreco.Text = dgvLista.Rows[e.RowIndex].Cells[3].Value.ToString();
            }
        }

        private void SalvaMudancas()
        {
            try
            {
                SqlCommandBuilder cbLivros =
                    new SqlCommandBuilder(daLivros);

                DataTable dtLivros = dsLivros.Tables["tblLivros"];
                DataRow drLivros;

                if (isIncluirFlag)
                {
                    drLivros = dtLivros.NewRow();

                    drLivros["titulo"] = txtTitulo.Text;
                    drLivros["preco"] = Convert.ToDecimal(txtPreco.Text);
                    dtLivros.Rows.Add(drLivros);
                    
                }
                else if (isEditarFlag)
                {
                    drLivros = dtLivros.Rows.Find(dgvLista.SelectedRows[0].Cells[0].Value);

                    drLivros.BeginEdit();
                    drLivros["titulo"] = txtTitulo.Text;
                    drLivros["preco"] = Convert.ToDecimal(txtPreco.Text);
                    drLivros.EndEdit();
                    
                }

                // envia mensagem ao SQL Server para persistir dados
                daLivros.Update(dsLivros, "tblLivros");
                formataGridView();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message.ToString());
            }

            AtualizaDataSet();

            SetButtons(true);
            SetEnabled(false);
        }

        private void AtualizaDataSet()
        {
            try
            {
                daLivros.Fill(dsLivros, "tblLivros");
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message.ToString());
            }
        }

        private void SetButtons(bool bVal)
        {
            btnIncluir.Visible   = bVal;
            btnEditar.Visible    = bVal;
            btnDeletar.Visible   = bVal;
            btnPesquisar.Visible = bVal;
            btnAtualizar.Visible = bVal;

            btnSave.Visible      = !bVal;
            btnCancel.Visible    = !bVal;
        }

        private void SetEnabled(bool bVal)
        {
            txtTitulo.Enabled    = bVal;
            txtPreco.Enabled     = bVal;
        }

        private void btnSalvar_Click(object sender, EventArgs e)
        {
            SalvaMudancas();
        }

        private void btnAtualizar_Click(object sender, EventArgs e)
        {
            AtualizaDataSet();   
        }

        private void btnCancelar_Click(object sender, EventArgs e)
        {
            SetButtons(true);
            SetEnabled(false);

            isIncluirFlag  = false;
            isEditarFlag = false;
        }

        private void btnEditar_Click(object sender, EventArgs e)
        {
            SetEnabled(true);
            SetButtons(false);

            isEditarFlag = true;
        }

        private void btnDeletar_Click(object sender, EventArgs e)
        {
            if (MessageBox.Show("Tem certeza?", "Deletar", MessageBoxButtons.YesNo) == DialogResult.Yes)
            {
                try
                {
                    DataTable dtLivros = dsLivros.Tables["tblLivros"];
                    DataRow drLivros;


                    if (dgvLista.SelectedRows.Count > 0)
                    {
                        // deleta a linha selecionada
                        drLivros = dtLivros.Rows.Find(dgvLista.SelectedRows[0].Cells[0].Value);
                        drLivros.Delete();

                        SqlCommandBuilder cbLivros =
                            new SqlCommandBuilder(daLivros);

                        // envia mudanças ao SQL Server
                        daLivros.Update(dsLivros, "tblLivros");
                        AtualizaDataSet();
                    }
                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message.ToString());
                }
            }
        }

        private void mnuSair_Click(object sender, EventArgs e)
        {
            if (MessageBox.Show("Deseja encerrar a aplicação ? ", "Livros",
                   MessageBoxButtons.YesNo, MessageBoxIcon.Question)
                   == DialogResult.Yes)
            {
                Application.Exit();
            }
        }

        private void btnPesquisar_Click(object sender, EventArgs e)
        {
            if (txtPesquisar.Text.Trim().Length > 0)
            {
                DataTable dtLivros = dsLivros.Tables["tblLivros"];
                DataView dvLivros = new DataView(dtLivros);

                // procura registros
                dvLivros.RowFilter = String.Concat("titulo LIKE '%", txtPesquisar.Text, "%'");
                dgvLista.DataSource = dvLivros;
            }
            else
            {
                // exibe todos os registros
                dgvLista.DataSource = dsLivros;
                dgvLista.DataMember = "tblLivros";
            }
            formataGridView();
        }
        private void formataGridView()
        {
            var gdvCli = dgvLista;
            gdvCli.AutoSizeRowsMode = DataGridViewAutoSizeRowsMode.DisplayedCellsExceptHeaders;
            gdvCli.ColumnHeadersBorderStyle = DataGridViewHeaderBorderStyle.Single;
            //altera a cor das linhas alternadas no grid
            gdvCli.RowsDefaultCellStyle.BackColor = Color.White;
            gdvCli.AlternatingRowsDefaultCellStyle.BackColor = Color.Aquamarine;
            //altera o nome das colunas
            gdvCli.Columns[0].HeaderText = "Código";
            gdvCli.Columns[1].HeaderText = "Autor";
            gdvCli.Columns[2].HeaderText = "Titulo";
            gdvCli.Columns[3].HeaderText = "Preço";
            gdvCli.Columns[0].Width = 50;
            gdvCli.Columns[1].Width = 50;
            gdvCli.Columns[2].Width = 260;
            gdvCli.Columns[3].Width = 70;
            //formata a preco
            gdvCli.Columns[3].DefaultCellStyle.Format = "c";
            gdvCli.Columns[3].DefaultCellStyle.Alignment = DataGridViewContentAlignment.BottomRight;
            //seleciona a linha inteira
            gdvCli.SelectionMode = DataGridViewSelectionMode.FullRowSelect;
            //não permite seleção de multiplas linhas
            gdvCli.MultiSelect = false;
            // exibe nulos formatados
            gdvCli.DefaultCellStyle.NullValue = " - ";
            //permite que o texto maior que célula não seja truncado
            gdvCli.DefaultCellStyle.WrapMode = DataGridViewTriState.True;
        }

    }
}
